/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface TlsProviderConfig {
    /**
    * Alias name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tls/4.0.4/docs#alias TlsProvider#alias}
    */
    readonly alias?: string;
    /**
    * proxy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tls/4.0.4/docs#proxy TlsProvider#proxy}
    */
    readonly proxy?: TlsProviderProxy;
}
export interface TlsProviderProxy {
    /**
    * When `true` the provider will discover the proxy configuration from environment variables. This is based upon [`http.ProxyFromEnvironment`](https://pkg.go.dev/net/http#ProxyFromEnvironment) and it supports the same environment variables (default: `true`).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tls/4.0.4/docs#from_env TlsProvider#from_env}
    */
    readonly fromEnv?: boolean | cdktf.IResolvable;
    /**
    * Password used for Basic authentication against the Proxy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tls/4.0.4/docs#password TlsProvider#password}
    */
    readonly password?: string;
    /**
    * URL used to connect to the Proxy. Accepted schemes are: `http`, `https`, `socks5`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tls/4.0.4/docs#url TlsProvider#url}
    */
    readonly url?: string;
    /**
    * Username (or Token) used for Basic authentication against the Proxy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tls/4.0.4/docs#username TlsProvider#username}
    */
    readonly username?: string;
}
export declare function tlsProviderProxyToTerraform(struct?: TlsProviderProxy): any;
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/tls/4.0.4/docs tls}
*/
export declare class TlsProvider extends cdktf.TerraformProvider {
    static readonly tfResourceType = "tls";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/tls/4.0.4/docs tls} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options TlsProviderConfig = {}
    */
    constructor(scope: Construct, id: string, config?: TlsProviderConfig);
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    resetAlias(): void;
    get aliasInput(): string | undefined;
    private _proxy?;
    get proxy(): TlsProviderProxy | undefined;
    set proxy(value: TlsProviderProxy | undefined);
    resetProxy(): void;
    get proxyInput(): TlsProviderProxy | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
